"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.defineImports = void 0;
const fragmentType_template_1 = require("./fragmentType.template");
const _store_1 = require("../store");
const defineImports = () => {
    let template = '';
    const { isCodeGen, codegenFunctions, codegenVueHooks, codegenReactHooks, apolloVersion, } = _store_1.ParametersStore;
    if (isCodeGen) {
        template = `
    import { OperationDefinitionNode } from 'graphql';
    ${fragmentType_template_1.guessFragmentTypeTemplate}
    `;
        if (codegenReactHooks) {
            template += `
      import { useMutation, useQuery, useSubscription, QueryHookOptions, MutationHookOptions, SubscriptionHookOptions, MutationTuple } from '@apollo/react-hooks'
      import { DocumentNode, gql } from '${apolloVersion === 3 ? '@apollo/client' : 'apollo-client'}'
      `;
        }
        if (codegenVueHooks) {
            template += `
      import { Ref } from '@vue/composition-api'
      import { useMutation, useQuery, useSubscription, UseQueryOptions, UseMutationOptions, UseSubscriptionOptions } from '@vue/apollo-composable'
      import { DocumentNode, gql } from '${apolloVersion === 3 ? '@apollo/client' : 'apollo-client'}'

      export type ReactiveFunction<TParam> = () => TParam;
      `;
        }
        if (codegenFunctions) {
            if (apolloVersion === 3) {
                template += `
        import { ApolloClient, execute, DocumentNode, gql } from '@apollo/client/core';
      `;
            }
            else {
                template += `
        import ApolloClient, { QueryOptions, OperationVariables, MutationOptions, ObservableQuery } from 'apollo-client';
        import { execute } from 'apollo-link';
      `;
            }
        }
    }
    return template;
};
exports.defineImports = defineImports;
